## CONTENTS OF THIS FILE ##

 * Introduction
 * Installation
 * Usage
 * How Can You Contribute?
 * Maintainers

## INTRODUCTION ##

Author and maintainer: Pawel Ginalski (gbyte)
 * Drupal: https://www.drupal.org/u/gbyte
 * Homepage: https://gbyte.dev/

This module allows for programmatic creating and sending of emails. It exposes a
OOP and twig template based API replacing the messy hook based approach used by
Drupal core. This uses Drupal services in the background and does not have any
additional dependencies.

This is a pure API module and is to be used programmatically (in other modules).

## INSTALLATION ##

See https://www.drupal.org/documentation/install/modules-themes/modules-8
for instructions on how to install or update Drupal modules.

## USAGE ##

### Using the manager with email class & email template

1. Implement `Drupal\my_module\Email` extending `Drupal\mail_composer\Email`:
    
    ```php
   <?php
   
   namespace Drupal\my_module\Email;
   
   use Drupal\mail_composer\Email\Email;
   
   class TestEmail extends Email {
   
     /**
      * @inheritDoc
      */
     public function getSubject(): string {
       return $this->t('My test email');
     }
   
     /**
      * @inheritDoc
      */
     public function getFrom(): string {
       return 'foobar@foo.bar';
     }
   
   }
    ```
   
   Other methods can be overridden as needed.

2. Implement `my_module/templates/emails/TestEmail.html.twig`:
    
    ```twig
   This is the body of the email with variable {{ my_variable_1 }} and
   {{ my_variable_2 }}.
    ```

   HTML templates can be used instead when using a module like swiftmailer.

3. Send the email:
    
    ```php
   /** @var \Drupal\mail_composer\Email\Manager $manager */
   $manager = \Drupal::service('mail_composer.manager');

   // When using Email class:
   $email = new \Drupal\my_module\Email\TestEmail(['my_variable_1' => 'foo', 'my_variable_2' => 'bar']);
   $manager->compose($email)->setTo('foo@bar.bar')->send();
   ```
   All email settings defined in the TestEmail class (optional) can be 
   overridden with the manager.

### Using the manager with email class without template

Just skip step 2 above and either add `TestEmail::getBody()` or use
`$manager::setBody` (see below).

### Using just the manager

```php
/** @var \Drupal\mail_composer\Email\Manager $manager */
$manager = \Drupal::service('mail_composer.manager');

$manager->setSubject('My test email')
->setFrom('foobar@foo.bar')
->setTo('foo@bar.bar')
->setBody(['This is the body of the email with variable foo and bar.'])
->send();
```

### MULTILINGUAL EMAILS ###

- The email subject can be translated using `t()`.
- The email language can be set via `$manager->setLangcode()` or in the
  `TestEmail` class.
- It is possible to have per-language email body templates by adding a suffix 
  for non-default languages, e.g. `TestEmail-de.html.twig`.
- When not using email body templates, `t()` can be used to translate the body.

## HOW CAN YOU CONTRIBUTE? ##

 * Report any bugs, feature or support requests in the issue tracker; if
   possible help out by submitting patches.
   http://drupal.org/project/issues/simple_sitemap

 * If you would like to say thanks and support the development of this module, a
   donation will be much appreciated.
   https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=5AFYRSBLGSC3W

 * Feel free to contact me for paid support: https://gbyte.dev/contact

## MAINTAINERS ##

Current maintainers:
 * Pawel Ginalski (gbyte) - https://www.drupal.org/u/gbyte
